Learn R Programming

gnomonicM (version 1.0.1)

print.gnomos: Print method for gnomos class

Description

Print method for gnomos class

Usage

# S3 method for gnomos
print(x, ...)

Arguments

x

an object class 'gnomos'.

Additional arguments to the print method.

Value

The values of the proportionality constant (a), constant proportion of the overall natural death rate (G) and a data.frame with the duration and natural mortality for each gnomonic interval. #' @examples model <- gnomonic(nInterval = 7, eggDuration = 2, addInfo = NULL, longevity = 365, fecundity = 200000, a_init = 2)

print(model)